
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

//-------------------------------------------------//
//                                                 //
//                CLASSE FENETRE                   //
//                                                 //
//-------------------------------------------------//
 

public class Fenetre extends JFrame implements ActionListener{
    
    private JDesktopPane desktop;

    // Declaration des fenetres   
    private FenEditeur editeur;
    private FenViewer viewer;
    private FenLegende legende;

    // Declaration de la barre de menu
    private JMenuBar menu = new JMenuBar();
    private JMenu pomme = new JMenu();
    private JMenu fichier = new JMenu();
    private JMenuItem itemViewer = new JMenuItem();
    private JMenuItem itemEditeur = new JMenuItem();
    private JMenuItem nouveau = new JMenuItem();
    private JMenuItem ouvrir = new JMenuItem();
    private JMenuItem enregistrer = new JMenuItem();
    private JMenuItem quitter = new JMenuItem();
    

    private GenerateXML xml;
    private Graphe graphe;
  
    //---------------------------------------------------
    // Constructeur:
    // C dans le nom ...
    //---------------------------------------------------
    
    public Fenetre(String s, Graphe g) {
	
	setTitle(s);
	setSize(750,530);
	setLocation(50,50);
	addWindowListener(new WindowAdapter()
	    {
		public void windowClosing(WindowEvent e)
		{
		    System.exit(0);
		}
	    });
	graphe=g;
	xml=new GenerateXML(graphe);
	// Mise en place du system des JInternealFrame
	desktop = new JDesktopPane(); 
	// Creation des Fenetres
	createLegende();
	createViewer();
	createEditeur();
	setContentPane(desktop);
	
	editeur.setVisible(true);
	// Creation du menu
	creerMenu();
	
	setJMenuBar(menu);
	
	desktop.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);
    
    
    }

    //---------------------------------------------------
    // Fonction creerMenu():
    // Creation du menu
    //---------------------------------------------------
 
    protected void creerMenu() {
    
    
	pomme.setText("Pomme");
	fichier.setText("Fichier");
	itemViewer.setText("Viewer");
	itemViewer.addActionListener(this);
	itemEditeur.setText("Editeur");
	itemEditeur.addActionListener(this);
	nouveau.setText("Nouveau");
	nouveau.addActionListener(this);
	ouvrir.setText("Ouvrir");
	ouvrir.addActionListener(this);
	enregistrer.setText("Enregistrer");
	enregistrer.addActionListener(this);
	quitter.setText("Quitter");
	quitter.addActionListener(this);
	
	pomme.add(itemViewer);
	pomme.add(itemEditeur);
	fichier.add(nouveau);
	fichier.add(ouvrir);
	fichier.add(enregistrer);
	fichier.add(quitter);
    
	menu.add(pomme);
	menu.add(fichier);
	
    }

    //---------------------------------------------------
    // Fonction creerLegende():
    // Creation de la fenetre de legende
    //---------------------------------------------------
   
  protected void createLegende() {
    legende = new FenLegende();
    legende.setVisible(false); //necessary as of 1.3
    desktop.add(legende);
  }

    //---------------------------------------------------
    // Fonction creerViewer():
    // Creation de la fenetre du viewer
    //---------------------------------------------------
  
  protected void createViewer() {
    viewer = new FenViewer(graphe);
    viewer.setVisible(false); //necessary as of 1.3
    desktop.add(viewer);
    /*	try {
	viewer.setSelected(true);
	} catch (java.beans.PropertyVetoException e) {}
    */
    }

    //---------------------------------------------------
    // Fonction creerEditeur():
    // Creation de la fenetre d'edition
    //---------------------------------------------------

  protected void createEditeur() {
    editeur = new FenEditeur(graphe);
    editeur.setVisible(false); //necessary as of 1.3
    desktop.add(editeur);
    /*
      try {
      editeur.setSelected(true);
      } catch (java.beans.PropertyVetoException e) {}
    */
  }
    
    //---------------------------------------------------
    // Fonction actionPerformed():
    // 
    //---------------------------------------------------
 
  public void actionPerformed(ActionEvent e) {
    
    if(e.getSource()==itemEditeur) {
      
      viewer.setVisible(false);
      legende.setVisible(false);
      editeur.maj();
      editeur.setVisible(true);	
      nouveau.setEnabled(true);
      try {
	editeur.setSelected(true);
      } catch (java.beans.PropertyVetoException ee) {}

    }	

    if(e.getSource()==itemViewer) {
	if(graphe.getSource()==null || graphe.getPuit()==null)
	    {
		//System.out.println("Probleme de graphe");
		JOptionPane.showMessageDialog(this,"Veuillez selectionner une source et un puit avant d'aller plus loin !!!","Probleme de graphe",JOptionPane.PLAIN_MESSAGE);
	    }
	else
	    {
		if(graphe.estConnexe())
		    {
		      graphe.recaler();
		      //Tester le graphe avant de lancer le viewer
		      editeur.setVisible(false);
		      viewer.maj();
		      legende.setVisible(true);
		      viewer.setVisible(true);
		      
		      nouveau.setEnabled(false);
		      try {
			viewer.setSelected(true);
		      } catch (java.beans.PropertyVetoException ee) {}
		    }		
		else
		  {
			//System.out.println("Problem de Graphe !!!");
			JOptionPane.showMessageDialog(this,"Structure du Graphe incorecte\nVeuillez verifier la structure du graphe avant d'aller plus loin !!!","Probleme de graphe",JOptionPane.PLAIN_MESSAGE);
		    }
	    }
    }
	
    if(e.getSource()==nouveau) {
	graphe.clear();
	//System.out.println("Nouveau Graphe");
	editeur.maj();
	editeur.repaint();

    }
    if(e.getSource()==ouvrir) {

      //Recuperation du nom de fichier
      String fichier = "";
      JFileChooser chooser = new JFileChooser();
      int returnVal = chooser.showOpenDialog(this);
      if(returnVal == JFileChooser.APPROVE_OPTION) {

	String temp = chooser.getCurrentDirectory().getAbsolutePath();
	//System.out.println("Chemin : "+temp);
	fichier = temp+"/"+chooser.getSelectedFile().getName();
	//System.out.println("Chemin : "+fichier);
      }
      
      
      //Parser de fichier
      //System.out.println("Avant lecture ...");
      if(fichier!="") {
	xml.parserXML(fichier);
	//System.out.println("Apres parser ... !!!");
      }
      else {
	System.out.println("Erreur d'ouverture : pas de fichier slectionne");
      }
      editeur.maj();
      viewer.maj();
      viewer.repaint();
      editeur.repaint();
    } 
    if(e.getSource()==enregistrer) {
      
      if(graphe.getSource()==null || graphe.getPuit()==null)
	{
	  System.out.println("Probleme de graphe");
	  JOptionPane.showMessageDialog(this,"Veuillez selectionner une source et un puit avant d'aller plus loin !!!","Probleme de graphe",JOptionPane.PLAIN_MESSAGE);
	}
      else
	    {
	      if(graphe.estConnexe())
		{
		  graphe.recaler();
		  //Recuperation du nom de fichier
		  String fichierSave = "";
		  JFileChooser chooser2 = new JFileChooser();
		  int returnVal2 = chooser2.showSaveDialog(this);
		  if(returnVal2 == JFileChooser.APPROVE_OPTION) {
		    String path = chooser2.getCurrentDirectory().getAbsolutePath();
		    //System.out.println("Chemin : "+path);
		    fichierSave = path+"/"+chooser2.getSelectedFile().getName();
		    //System.out.println("Chemin : "+fichierSave);
		    
		    
		  }
		  
		  //Generer le fichier XML
		  if(fichierSave!="")
		    {

		      try{
			xml.generer(fichierSave);
		      }catch(java.io.IOException ee){}
		     
		    }
		  else
		    {
		      System.out.println("Erreur nom de fichier : Pas sauvegarde");
		    } 
		}
	      else
		{
		  JOptionPane.showMessageDialog(this,"Structure du Graphe incorecte\nVeuillez verifier la structure du graphe avant d'aller plus loin !!!","Probleme de graphe",JOptionPane.PLAIN_MESSAGE);
		

		}
 
	    }
    }
    if(e.getSource()==quitter) {
	//demande si sauvegarder puis quitter ...
   	System.exit(0);
    }
 
 }
 
//--------------------------------------------------------------//
//                                                              //
//                   Fin de la CLASSE				//
//                                                              //
//--------------------------------------------------------------//

   
}
